.. WCSAxes documentation master file, created by
   sphinx-quickstart on Tue Feb 25 20:57:56 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to WCSAxes's documentation!
===================================

WCSAxes is a framework for making plots of Astronomical data in Matplotlib. It
is affiliated with the `Astropy <http://www.astropy.org>`__ project and is
intended for inclusion in the Astropy package once stable.

.. toctree::
   :maxdepth: 1

   installation.rst
   getting_started.rst
   ticks_labels_grid.rst
   overlays.rst
   overlaying_coordinate_systems.rst
   slicing_datacubes.rst
   initializing_axes.rst
   controlling_axes.rst
   custom_frames.rst
   api.rst



